@@ -497,6 +497,106 @@ namespace SGA
         }
     }
 
+    void GameConfigParser::parseEffects(const YAML::Node& effectsNode, GameConfig& config, FunctionParser& parser, ParseContext& context, std::vector<boost::variant<std::shared_ptr<Effect>, std::shared_ptr<EffectPack>>>& effects, std::vector<std::pair<TargetType, std::vector<std::shared_ptr<Condition>>>>& /*targets*/) const
+    {
+        if (effectsNode.IsMap())
+        {
+            for (const auto& effect : effectsNode)
+            {
+                if (effect.second.IsMap())
+                {
+                    //Check if is custom effect, conditional or random
+                    if (effect.first.as<std::string>() == "ConditionalEffect")
+                    {
+                        //std::cout << "Parsing conditional effect" << std::endl;
+                        EffectPack conditionEffect= EffectPack(EffectPack::EffectPackType::Conditional);
+
+                        //std::cout << "  Parsign list of effects in condition" << std::endl;
+                        //Parse condition of condiion pack
+                        std::vector<std::shared_ptr<Condition>> conditionConditionsList;
+                        auto effectConditions = effect.second["Conditions"].as<std::vector<std::string>>(std::vector<std::string>());
+                        parser.parseFunctions(effectConditions, conditionConditionsList, context);
+                        //Parse effects of condition pack
+                        std::vector<boost::variant<std::shared_ptr<Effect>, std::shared_ptr<EffectPack>>> conditionEffects;
+                        parseEffects(effect.second["Effects"], config, parser, context, conditionEffects, conditionEffect.actionTargets);
+
+                        conditionEffect.conditionEffects = { conditionConditionsList, conditionEffects };
+
+                        effects.emplace_back(std::make_shared<EffectPack>(conditionEffect));
+                    }
+                    else if (effect.first.as<std::string>() == "RandomEffect")
+                    {
+                        //std::cout << "Parsing random effect" << std::endl;
+                        EffectPack randomEffect = EffectPack(EffectPack::EffectPackType::Random);
+                       
+                        for (auto& target : effect.second.as<std::map<float, YAML::Node>>())
+                        {
+                            //std::cout << "  Parsign list of random" << std::endl;
+                            std::vector<boost::variant<std::shared_ptr<Effect>, std::shared_ptr<EffectPack>>> conditionEffects;
+                            parseEffects(target.second, config, parser, context, conditionEffects, randomEffect.actionTargets);
+
+                            std::pair<float, std::vector<boost::variant<std::shared_ptr<Effect>, std::shared_ptr<EffectPack>>>> pair;
+                            pair = { target.first, conditionEffects };
+                            randomEffect.randomEffects.emplace_back(pair);
+                        }
+
+                        effects.emplace_back(std::make_shared<EffectPack>(randomEffect));
+                    }
+                    else if (effect.first.as<std::string>() == "SampleEffect")
+                    {
+                        //std::cout << "Parsign effect: " << effect.first.as<std::string>() << std::endl;
+                        EffectPack targetEffect = EffectPack(EffectPack::EffectPackType::Sample);
+                        if (effect.second["Targets"].IsDefined())
+                            for (auto& target : effect.second["Targets"].as<std::map<std::string, YAML::Node>>())
+                            {
+                                //std::cout << "Parsign target: " << target.first << std::endl;
+                                TargetType newTarget;
+                                context.targetIDs.emplace(target.first, static_cast<int>(context.targetIDs.size()));
+                                newTarget = parseTargetType(target.second, config);
+
+                                std::vector<std::shared_ptr<Condition>> targetConditionsList;
+                                //// Parse target conditions
+                                auto targetConditions = target.second["Conditions"].as<std::vector<std::string>>(std::vector<std::string>());
+                                parser.parseFunctions(targetConditions, targetConditionsList, context);
+                                targetEffect.actionTargets.emplace_back(newTarget, targetConditionsList);
+                            }                        
+
+                        if (effect.second["Effects"].IsDefined())
+                        {
+                            //std::cout << "  Parsign list of effects" << std::endl;
+                            parseEffects(effect.second["Effects"], config, parser, context, targetEffect.effects, targetEffect.actionTargets);
+                        }
+                        else
+                        {
+                            throw(std::runtime_error("Effects not defined in SampleEffect"));
+                        }
+                        effects.emplace_back(std::make_shared<EffectPack>(targetEffect));
+                    }
+                }
+                else if (effect.second.IsSequence())
+                {
+                    //std::cout << "Parsing list of regular effects effects";
+                    auto effectsText = effect.second.as<std::vector<std::string>>(std::vector<std::string>());
+                    std::vector<std::shared_ptr<Effect>> bucket;
+                    parser.parseFunctions(effectsText, bucket, context);
+                    for (auto& effectTemp : bucket)
+                    {
+                        effects.emplace_back(effectTemp);
+                    }
+                }
+            }
+        }
+        else if (effectsNode.IsSequence())
+        {
+            auto effectsText = effectsNode.as<std::vector<std::string>>(std::vector<std::string>());
+            std::vector<std::shared_ptr<Effect>> bucket;
+            parser.parseFunctions(effectsText, bucket, context);
+            for (auto& effect : bucket)
+            {
+                effects.emplace_back(effect);
+            }
+        }
+    }
     void GameConfigParser::parseActions(const YAML::Node& actionsNode, GameConfig& config) const
     {
         if (!actionsNode.IsDefined())
@@ -509,14 +609,14 @@ namespace SGA
         auto context = ParseContext::fromGameConfig(config);
 
         //Generate end turn action
-        ActionType type;
-        type.setID(static_cast<int>(config.actionTypes.size()));
-        type.setName("EndTurn");
+        ActionType actionType;
+        actionType.setID(static_cast<int>(config.actionTypes.size()));
+        actionType.setName("EndTurn");
         context.targetIDs.emplace("Source", 0);
-        type.setSourceType(ActionSourceType::Player);
-        type.setEndTick(true);
+        actionType.setSourceType(ActionSourceType::Player);
+        actionType.setEndTick(true);
 
-        config.actionTypes.emplace(type.getID(), std::move(type));
+        config.actionTypes.emplace(actionType.getID(), std::move(actionType));
 
         for (const auto& nameTypePair : actionsNode.as<std::map<std::string, YAML::Node>>())
         {
@@ -550,8 +650,11 @@ namespace SGA
             parser.parseFunctions(preconditions, type.getPreconditions(), context);
 
             // Parse effects
-            auto effects = nameTypePair.second["Effects"].as<std::vector<std::string>>(std::vector<std::string>());
-            parser.parseFunctions(effects, type.getEffects(), context);
+            /*auto effects = nameTypePair.second["Effects"].as<std::vector<std::string>>(std::vector<std::string>());
+            parser.parseFunctions(effects, type.getEffects(), context);*/
+            std::vector<boost::variant<std::shared_ptr<Effect>, std::shared_ptr<EffectPack>>> effects;
+            parseEffects(nameTypePair.second["Effects"], config, parser,context, effects, type.getTargets());
+            type.getEffects2() = effects;
 
             type.setContinuous(false);
 
