@@ -175,11 +175,11 @@ namespace  SGA
 
 	bool InRange::isFullfiled(const GameState& state, const std::vector<ActionTarget>& targets) const
 	{
-		const auto& source = sourceEntity.getEntity(state, targets);
+		const auto& source = sourceEntity.getPosition(state, targets);
 		const auto& target = targetEntity.getPosition(state, targets);
 		auto dist = distance.getConstant(state, targets);
 		//std::cout << "	InRange: " << source.getPosition().distance(target) <<"<=" << dist<<std::endl;
-		return source.getPosition().distance(target) <= dist;
+		return source.distance(target) <= dist;
 	}
 
 	OutRange::OutRange(const std::string exp, const std::vector<FunctionParameter>& parameters)
@@ -239,15 +239,17 @@ namespace  SGA
 		{
 			auto grid = gridLevel.getConstant(state, targets);
 
-			return state.getEntitiesAtConst(pos, grid).size() != 0;
+			return state.getEntitiesAtConst(pos, static_cast<int>(grid)).size() != 0;
 		}
-		else if (gridLevel.getType() == FunctionParameter::Type::EntityTypeReference || 
+		else if (gridLevel.getType() == FunctionParameter::Type::EntityTypeReference ||
 			gridLevel.getType() == FunctionParameter::Type::ArgumentReference)
 		{
 			auto type = gridLevel.getEntityType(state, targets);
 
 			return state.getEntitiesAtConst(pos, type.getID()).size() != 0;
 		}
+		else
+			return false;
 	}
 
 	IsNotOccupied::IsNotOccupied(const std::string exp, const std::vector<FunctionParameter>& parameters)
@@ -277,15 +279,16 @@ namespace  SGA
 		{
 			auto grid = gridLevel.getConstant(state, targets);
 
-			return state.getEntitiesAtConst(pos, grid).size() == 0;
+			return state.getEntitiesAtConst(pos, static_cast<int>(grid)).size() == 0;
 		}
-		else if (gridLevel.getType() == FunctionParameter::Type::EntityTypeReference || 
+		else if (gridLevel.getType() == FunctionParameter::Type::EntityTypeReference ||
 			gridLevel.getType() == FunctionParameter::Type::ArgumentReference)
 		{
 			auto type = gridLevel.getEntityType(state, targets);
 
 			return state.getEntitiesAtConst(pos, type.getGrid()).size() == 0;
 		}
+		else return false;
 	}
 
 	IsTile::IsTile(const std::string exp, const std::vector<FunctionParameter>& parameters)
